@@ -113,6 +113,7 @@ class Printer(FlowElement):
     def process(self,elem):
         print self.prefix,elem
         self.out_elem(elem)
+        self.out_in_elem(elem)
 
 class ElementTransformer(FlowElement):
     def __init__(self):
@@ -121,7 +122,9 @@ class ElementTransformer(FlowElement):
         self.error_objects=[NullProcessor()]
     def process(self,elem):
         try:
-            self.out_elem(self.transform(elem))
+            e2=self.transform(elem)
+            self.out_elem(e2)
+            self.out_in_elem({'in':elem,'out':e2})
         except:
             error=traceback.format_exc()
             elem['error']=error
